from PySide6.QtWidgets import QMessageBox


class LogicButton:
    LogicButton = QMessageBox.StandardButton
    YES = QMessageBox.StandardButton.Yes
    NO = QMessageBox.StandardButton.No
    OK = QMessageBox.StandardButton.Ok
    CANCEL = QMessageBox.StandardButton.Cancel
